@@ -29,14 +29,14 @@ Q_OBJECT
 		blinken();
 		~blinken();
 
-		virtual QSize sizeHint() const;
+		QSize sizeHint() const override;
 		
 	protected:
-		void paintEvent(QPaintEvent *);
-		void mouseMoveEvent(QMouseEvent *e);
-		void mousePressEvent(QMouseEvent *e);
-		void keyPressEvent(QKeyEvent *e);
-		void keyReleaseEvent(QKeyEvent *e);
+		void paintEvent(QPaintEvent *) override;
+		void mouseMoveEvent(QMouseEvent *e) override;
+		void mousePressEvent(QMouseEvent *e) override;
+		void keyPressEvent(QKeyEvent *e) override;
+		void keyReleaseEvent(QKeyEvent *e) override;
 		
 	private slots:
 		void checkHS();
