@@ -11,6 +11,7 @@
 
 #include <kaboutdata.h>
 #include <klocalizedstring.h>
+#include <KCrash>
 #include <KDBusService>
 #include <kdelibs4configmigrator.h>
 
@@ -33,6 +34,8 @@ int main(int argc, char *argv[])
 
 	KAboutData::setApplicationData(about);
 
+	KCrash::initialize();
+
 	Kdelibs4ConfigMigrator migrate(QStringLiteral("blinken"));
 	migrate.setConfigFiles(QStringList() << QStringLiteral("blinkenrc"));
 	migrate.migrate();
